<?php
/*
Plugin Name: Auto Update ALT & TITLE Image Post Title
Description: Atualiza automaticamente os atributos ALT e TITLE das imagens dos posts.
Version: 1.0
Author: Agência PNZ
Author URI: https://agenciapnz.com/plugins/
Plugin URI: https://agenciapnz.com/plugins/auto-update-alt-title-image-post-title
*/

// Agendar o evento de atualização automática ao publicar um post
function pnz_aua_schedule_update($post_ID) {
    if (get_post_type($post_ID) !== 'post') return;
    
    wp_schedule_single_event(time() + 300, 'pnz_aua_update_post_images', array($post_ID));
}
add_action('publish_post', 'pnz_aua_schedule_update');

// Função para atualizar as imagens do post
function pnz_aua_update_images($post_ID) {
    $post = get_post($post_ID);
    if (!$post) return;
    
    $title = get_the_title($post_ID);
    $content = $post->post_content;
    
    // Atualizar imagens dentro do conteúdo do post
    preg_match_all('/<img[^>]+src=["\']([^"\']+)["\'][^>]*>/i', $content, $matches);
    if (!empty($matches[1])) {
        foreach ($matches[1] as $img_url) {
            pnz_aua_update_image_meta($img_url, $title);
        }
    }
    
    // Atualizar imagem destacada
    $thumb_id = get_post_thumbnail_id($post_ID);
    if ($thumb_id) {
        pnz_aua_update_image_meta_by_id($thumb_id, $title);
    }
}
add_action('pnz_aua_update_post_images', 'pnz_aua_update_images');

// Atualizar metadados da imagem a partir da URL
function pnz_aua_update_image_meta($img_url, $title) {
    global $wpdb;
    
    $attachment_id = $wpdb->get_var($wpdb->prepare(
        "SELECT ID FROM $wpdb->posts WHERE guid = %s AND post_type = 'attachment'",
        $img_url
    ));
    
    if ($attachment_id) {
        pnz_aua_update_image_meta_by_id($attachment_id, $title);
    }
}

// Atualizar metadados da imagem a partir do ID
function pnz_aua_update_image_meta_by_id($attachment_id, $title) {
    $alt = get_post_meta($attachment_id, '_wp_attachment_image_alt', true);
    if (empty($alt)) {
        update_post_meta($attachment_id, '_wp_attachment_image_alt', $title);
    }
    
    $post_data = array(
        'ID'         => $attachment_id,
        'post_title' => $title,
    );
    
    if (get_the_title($attachment_id) === 'Auto Draft') {
        wp_update_post($post_data);
    }
}

// Criar página de atualização em massa
function pnz_aua_register_admin_menu() {
    add_submenu_page(
        'tools.php',
        'Atualizar ALT & TITLE',
        'Atualizar ALT & TITLE',
        'manage_options',
        'pnz-aua-bulk-update',
        'pnz_aua_bulk_update_page'
    );
}
add_action('admin_menu', 'pnz_aua_register_admin_menu');

// Página de atualização em massa
function pnz_aua_bulk_update_page() {
    echo '<div class="wrap">';
    echo '<h1>Atualizar ALT & TITLE das Imagens</h1>';
    echo '<form method="post">';
    echo '<input type="submit" name="pnz_aua_bulk_update" class="button-primary" value="Atualizar Agora">';
    echo '</form>';
    echo '</div>';
    
    if (isset($_POST['pnz_aua_bulk_update'])) {
        pnz_aua_bulk_update_images();
        echo '<div class="updated"><p>Imagens atualizadas com sucesso!</p></div>';
    }
}

// Atualização em massa
function pnz_aua_bulk_update_images() {
    global $wpdb;
    
    $images = $wpdb->get_results("SELECT ID, post_parent FROM $wpdb->posts WHERE post_type = 'attachment'");
    
    foreach ($images as $image) {
        if ($image->post_parent) {
            $title = get_the_title($image->post_parent);
            pnz_aua_update_image_meta_by_id($image->ID, $title);
        }
    }
}
